# IBM Generative AI Python SDK (Tech Preview)

[![License](https://img.shields.io/badge/License-Apache_2.0-blue.svg)](https://github.com/IBM/ibm-generative-ai/blob/main/LICENSE)
![PyPI](https://img.shields.io/pypi/v/ibm-generative-ai)
![PyPI - Downloads](https://img.shields.io/pypi/dm/ibm-generative-ai)
[![Coverage Status](https://coveralls.io/repos/github/IBM/ibm-generative-ai/badge.svg?branch=main)](https://coveralls.io/github/IBM/ibm-generative-ai?branch=main)
[![Build & Unit/Integration Tests](https://github.com/IBM/ibm-generative-ai/actions/workflows/main.yml/badge.svg?branch=main)](https://github.com/IBM/ibm-generative-ai/actions/workflows/main.yml)
[![E2E Tests](https://github.com/IBM/ibm-generative-ai/actions/workflows/e2e-test.yml/badge.svg)](https://github.com/IBM/ibm-generative-ai/actions/workflows/e2e-test.yml)


This is not the [watsonx.ai](https://www.ibm.com/products/watsonx-ai) Python SDK. This is the Python SDK for the Tech Preview program for IBM Foundation Models Studio. This SDK brings IBM Generative AI (GenAI) into Python programs and provides useful operations and types.

*You can start a trial version or request a demo via https://www.ibm.com/products/watsonx-ai.*

*Looking for the [watsonx.ai](https://www.ibm.com/products/watsonx-ai) Python SDK? Check out [watson-machine-learning-sdk](https://ibm.github.io/watson-machine-learning-sdk/foundation_models.html).*

*Looking for a NodeJS SDK version? Check out [IBM Generative AI NodeJS SDK](https://github.com/IBM/ibm-generative-ai-node-sdk)*

*Looking for a CLI? Check out [IBM Generative AI CLI](https://github.com/IBM/ibm-generative-ai-cli).*

> [!IMPORTANT]
> The SDK was recently rewritten and released under V2 (2024). See the [V2 migration guide](https://ibm.github.io/ibm-generative-ai/main/v2_migration_guide.html).

## Installation

```
pip install --upgrade ibm-generative-ai
```


### [📚 Documentation](https://ibm.github.io/ibm-generative-ai/)

### [📚 Examples](https://ibm.github.io/ibm-generative-ai/latest/rst_source/examples.html)

### [📚 V2 Migration Guide](https://ibm.github.io/ibm-generative-ai/latest/v2_migration_guide.html)


## Important Information for Contributors
- Do you want to contribute to the project? IBM Generative AI is an open-source project that welcomes the community to contribute with documentation, tests, bug corrections, and new functionality in the form of [extensions](EXTENSIONS.md). Please read our [code of conduct](CODE_OF_CONDUCT.md) to learn the expected behavior from participants that contribute to the project, and our [contribution guide](./CONTRIBUTING.md) to learn the gitflow and steps to submit pull requests.

<!-- vscode-markdown-toc-config
	numbering=false
	autoSave=true
	/vscode-markdown-toc-config -->
<!-- /vscode-markdown-toc -->
